﻿using System;
using System.Collections;
using UnityEngine;
using System.Collections.Generic;

using BehaviorDesigner.Runtime;
public class Reaction : MonoBehaviour
{
    [Serializable]
    public class AddMass
    {

        public float massMultip;
        public Rigidbody Obj;
        public float delay;


        public IEnumerator React()
        {

            yield return new WaitForSeconds(delay);
            Obj.mass*= massMultip;
            //Obj.gameObject.GetComponent<BehaviorTree>().enabled = false;
           
        }
    }
    [Serializable]
    public class NewObj
    {
       
        public GameObject perfab;
        public GameObject point;
        public float delay;


        public IEnumerator React()
        {
           
                yield return new WaitForSeconds(delay);
            GameObject newPlayer = Instantiate(perfab,point.transform.position,point.transform.rotation);
            
            newPlayer.GetComponent<Rigidbody>().mass = 1f;
           
        }
    }
    [Serializable]
    public class GetHitObjReaction
    {
        public ObjList objListToChange;
        //public string targetTag;
        public ColliderTrigger colliderTrigger;
        //public bool False_True;
        public float delay;


        public IEnumerator React()
        {
            if (colliderTrigger.hitObj.tag=="item")
            {
                yield return new WaitForSeconds(delay);
                if (DebugTrigger.debugBool)
                    Debug.Log(colliderTrigger.name+ "colliderTriggercolliderTriggercolliderTriggercolliderTriggercolliderTrigger");
                if(colliderTrigger.hitObj.GetComponent<Interactable>())
                colliderTrigger.hitObj.GetComponent<Interactable>().Interact();
                GameObject itemNew = Instantiate(colliderTrigger.hitObj,new Vector3(100000,100000,100000),Quaternion.EulerAngles(0,0,0));
               
                objListToChange.objList.Add(itemNew);
            }
        }
    }
    [Serializable]
    public class ColliderEnabledReaction
    {
        public string targetTag;
        public GameObject theCollider;
        public bool False_True;
        public float delay;


        public IEnumerator React()
        {
            if (theCollider)
            {
                yield return new WaitForSeconds(delay);

                theCollider.GetComponent<Collider>().enabled = False_True;
            }
        }
    }
    [Serializable]
    public class AnimationReaction
    {
        public Animator animator;
        public string animatorTrigger;
        public float delay;


        public IEnumerator React ()
        {
            if (animator)
            {
                yield return new WaitForSeconds (delay);

                animator.SetTrigger (animatorTrigger);
            }
        }
    }


    [Serializable]
    public class AudioReaction
    {
        public AudioSource audioSource;
        public AudioClip audioClip;
        public float delay;


        public void React ()
        {
            if (audioSource && audioClip)
            {
                audioSource.clip = audioClip;
                audioSource.PlayDelayed (delay);
            }
        }
    }


    [Serializable]
    public class BehaviourReaction
    {
        public Behaviour behaviourToEnable;
        public Behaviour behaviourToDisable;
        public float delay;


        public IEnumerator React ()
        {
            yield return new WaitForSeconds (delay);

            if (behaviourToEnable)
            {
                behaviourToEnable.enabled = true;
            }

            if (behaviourToDisable)
            {
                behaviourToDisable.enabled = false;
            }
        }
    }


    [Serializable]
    public class GameObjectReaction
    {
        public GameObject gameObjectToActivate;
        public GameObject gameObjectToDeactivate;
        public float delay;


        public IEnumerator React ()
        {
            yield return new WaitForSeconds (delay);

            if (gameObjectToActivate)
            {
                gameObjectToActivate.SetActive(true);
                if (DebugTrigger.debugBool)
                    Debug.Log("AAAAAAAAAAAAAAACTIVE"+gameObjectToActivate.name);
              
            }
            if (gameObjectToDeactivate)
            {
                gameObjectToDeactivate.SetActive(false);
                if (DebugTrigger.debugBool)
                    Debug.Log("DDDDDDDDDDEACTIVE"+gameObjectToDeactivate.name);
               
            }
        }
    }


    //[Serializable]
    //public class ItemReaction
    //{
    //    public GameObject pickedUpItem;
    //    public GameObject lostItem;
    //    public float delay;


    //    public IEnumerator React (Inventory inventory)
    //    {
    //        yield return new WaitForSeconds (delay);

    //        if (lostItem)
    //        {
    //            inventory.RemoveItem (lostItem);
    //        }
    //        if (pickedUpItem)
    //        {
    //            inventory.AddItem (pickedUpItem);
    //        }
    //    }
    //}


    [Serializable]
    public class SceneReaction
    {
        public bool loadAScene;
        public string sceneToLoad;
        public PersistentDataObject playerLocationPersistentDataObject;
        public Vector3 playerPosInLoadedScene;
        public Vector3 playerRotInLoadedScene;


        public void React (SceneController sceneController)
        {
            if (loadAScene)
            {
                playerLocationPersistentDataObject.position = playerPosInLoadedScene;
                playerLocationPersistentDataObject.rotation = Quaternion.Euler (playerRotInLoadedScene);
                sceneController.FadeAndLoadScene (sceneToLoad);
            }
        }
    }


    [Serializable]
    public class TextReaction
    {
        public TextManager textManager;
        public string message;
        public Color textColor = Color.white;
        public float delay;


        public void React ()
        {
            if (textManager)
            {
                textManager.DisplayMessage (message, textColor, delay);
            }
        }
    }


    [Serializable]
    public class UsedInteractableReaction
    {
        public Interactable interactable;


        public void React ()
        {
            if (interactable)
            {
                interactable.isUsed = true;
            }
        }
    }
    public AddMass[] addMass;
    public NewObj[] newObj;
    public GetHitObjReaction[] getHitObjReaction;
    public ColliderEnabledReaction[] colliderEnabledReaction;
    public AnimationReaction[] animationReactions;
    public AudioReaction[] audioReactions;
    public BehaviourReaction[] behaviourReactions;
    public GameObjectReaction[] gameObjectReactions;
    //public ItemReaction[] itemReactions;
    public SceneReaction sceneReaction;
    public TextReaction textReaction;
    public UsedInteractableReaction[] usedInteractableReactions;


	private SceneController sceneController;
    private Inventory inventory;


    private void Start ()
	{
		sceneController = FindObjectOfType<SceneController> ();
        inventory = FindObjectOfType<Inventory> ();
    }


    public void React ()
    {
        for (int i = 0; i < addMass.Length; i++)
        {
            StartCoroutine(addMass[i].React());
        }
        for (int i = 0; i < newObj.Length; i++)
        {
            StartCoroutine(newObj[i].React());
        }
        for (int i = 0; i < getHitObjReaction.Length; i++)
        {
            StartCoroutine(getHitObjReaction[i].React());
        }
        for (int i = 0; i < colliderEnabledReaction.Length; i++)
        {
            StartCoroutine(colliderEnabledReaction[i].React());
        }

        for (int i = 0; i < animationReactions.Length; i++)
        {
            StartCoroutine (animationReactions[i].React ());
        }

        for (int i = 0; i < audioReactions.Length; i++)
        {
            audioReactions[i].React ();
        }

        for (int i = 0; i < behaviourReactions.Length; i++)
        {
            StartCoroutine (behaviourReactions[i].React ());
        }

        for (int i = 0; i < gameObjectReactions.Length; i++)
        {
            StartCoroutine (gameObjectReactions[i].React ());
        }

        //for (int i = 0; i < itemReactions.Length; i++)
        //{
        //    StartCoroutine (itemReactions[i].React (inventory));
        //}

        sceneReaction.React(sceneController);

        textReaction.React ();

        for (int i = 0; i < usedInteractableReactions.Length; i++)
        {
            usedInteractableReactions[i].React ();
        }
    }
}
