﻿using UnityEngine;
using System.Collections.Generic;
using System.Linq;
using UnityEngine.UI;

public class TextManager : MonoBehaviour
{
    // A sub class to store each instruction to display text.
    public class Instruction
    {
        public string message;    // The text to be displayed.
        public Color textColor;   // The colour that the text should be displayed in.
        public float startTime;   // When the text should be displayed.
    }


    public Text text;                             // Reference to the Text component that will display the text.
    public float displayTimePerCharacter = 0.1f;  // The amount of time a single character adds to the time text is displayed for.
    public float additionalDisplayTime = 0.5f;    // Time added on top of the calculated time for a message to be displayed.


    private List<Instruction> instructions = new List<Instruction> ();    // Collection of instructions in the order that they should be displayed.
    private float clearTime;                                              // The time at which text should be cleared from the Text component.


    private void Update ()
    {
        // If there are instructions, and if the next instruction's start time has come...
        if (instructions.Count > 0 && Time.time >= instructions[0].startTime)
        {
            // ... display the message in the given colour and remove the instruction from the list.
            text.text = instructions[0].message;
            text.color = instructions[0].textColor;
            instructions.RemoveAt (0);
        }
        else if (Time.time >= clearTime)
        {
            // Otherwise if the time to clear the text has come, clear the text.
            text.text = string.Empty;
        }
    }


    public void DisplayMessage (string message, Color textColor, float delay)
    {
        float startTime = Time.time + delay;
        float displayDuration = message.Length * displayTimePerCharacter + additionalDisplayTime;
        float newClearTime = startTime + displayDuration;

        // The clear time is only changed if the newly calculated clear time is later than the current.
        if (newClearTime > clearTime)
            clearTime = newClearTime;

        // Create a new instruction based on the function parameters.
        Instruction newInstruction = new Instruction
        {
            message = message,
            textColor = textColor,
            startTime = Time.time + delay
        };

        // Add the instruction to the collection.
        instructions.Add (newInstruction);

        // Just in case the instructions fall out of order (if one had a particularly long delay) order them by start time.
        instructions = instructions.OrderBy (x => x.startTime).ToList ();
    }
}
