using UnityEngine;
using UnityEngine.EventSystems;
using System.Collections;

public class PlayerMovement : MonoBehaviour
{
	public UnityEngine.AI.NavMeshAgent agent;
	public Animator animator;
    public PersistentDataObject persistentLocationDataObject;


    private Interactable currentInteractable;


    private readonly int hashSpeedPara = Animator.StringToHash ("Speed");
    private readonly int hashLocomotionTag = Animator.StringToHash ("Locomotion");


    private const float walkingSpeedThreshold = 0.1f;


    private void Start ()
    {
        agent.updateRotation = false;

        transform.position = persistentLocationDataObject.position;
        transform.rotation = persistentLocationDataObject.rotation;
    }


    private void Update ()
    {
        AnimatePlayer ();

        ApproachingInteractable ();
    }


    private void ApproachingInteractable ()
    {
        if (currentInteractable != null)
        {
            float distanceToInteractable = Vector3.Distance (transform.position, agent.destination);
            if (Mathf.Approximately (distanceToInteractable, 0f))
            {
                transform.rotation = currentInteractable.interactionLocation.rotation;
                currentInteractable.Interact ();
                currentInteractable = null;
            }
        }
    }


	private void AnimatePlayer ()
	{
		float speed = agent.velocity.magnitude;

		animator.SetFloat (hashSpeedPara, speed);

		if (speed > walkingSpeedThreshold)
		{
			Vector3 flatVelocity = new Vector3 (agent.velocity.x, 0f, agent.velocity.z);
			transform.LookAt (transform.position + flatVelocity);
		}
	}
		

    public void OnGroundClick (BaseEventData data)
    {
        if (CharacterCanMove ())
        {
            currentInteractable = null;

            PointerEventData pData = (PointerEventData)data;

            agent.SetDestination (pData.pointerCurrentRaycast.worldPosition);
        }
    }


    public void OnInteractableClick (Interactable interactable)
    {
        if (CharacterCanMove ())
        {
            currentInteractable = interactable;

            agent.SetDestination (currentInteractable.interactionLocation.position);
        }
    }


    private bool CharacterCanMove ()
    {
		bool currentStateIsLocomotion = (animator.GetCurrentAnimatorStateInfo (0).tagHash == hashLocomotionTag);

        bool canMove;

        if (animator.IsInTransition (0))
        {
			canMove = currentStateIsLocomotion && (animator.GetNextAnimatorStateInfo (0).tagHash == hashLocomotionTag);
        }
        else
        {
            canMove = currentStateIsLocomotion;
        }

        return canMove;
    }
}
